from setuptools import setup, find_packages

setup(
    name='pydspy',
    version='0.1.0',
    packages=find_packages(),
    author='fswair',
    description='pydspy is a Python package.',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)